/// <reference types="react" />
import { BaseComponent } from '../../Utilities';
import { IColumn } from './DetailsList.types';
import { IDetailsRowProps } from './DetailsRow.types';
import { IDetailsRowCheckProps } from './DetailsRowCheck.types';
import { IDetailsRowStyleProps, IDetailsRowStyles } from './DetailsRow.types';
export declare const getClassNames: (getStyles?: ((props: IDetailsRowStyleProps) => Partial<IDetailsRowStyles>) | Partial<IDetailsRowStyles> | undefined, styleProps?: IDetailsRowStyleProps | undefined) => {
    root: string;
    cell: string;
    cellUnpadded: string;
    cellPadded: string;
    checkCell: string;
    isRowHeader: string;
    isMultiline: string;
    fields: string;
    cellMeasurer: string;
    checkCover: string;
    shimmer: string;
    shimmerIconPlaceholder: string;
    shimmerLeftBorder: string;
    shimmerBottomBorder: string;
    check: string;
};
export interface IDetailsRowSelectionState {
    isSelected: boolean;
    isSelectionModal: boolean;
}
export interface IDetailsRowState {
    selectionState?: IDetailsRowSelectionState;
    columnMeasureInfo?: {
        index: number;
        column: IColumn;
        onMeasureDone: (measuredWidth: number) => void;
    };
    isDropping?: boolean;
    groupNestingDepth?: number;
}
export declare class DetailsRowBase extends BaseComponent<IDetailsRowProps, IDetailsRowState> {
    private _root;
    private _cellMeasurer;
    private _focusZone;
    private _droppingClassNames;
    private _hasMounted;
    private _dragDropSubscription;
    constructor(props: IDetailsRowProps);
    componentDidMount(): void;
    componentDidUpdate(previousProps: IDetailsRowProps): void;
    componentWillUnmount(): void;
    componentWillReceiveProps(newProps: IDetailsRowProps): void;
    render(): JSX.Element;
    /**
     * measure cell at index. and call the call back with the measured cell width when finish measure
     *
     * @param {number} index (the cell index)
     * @param {(width: number) => void} onMeasureDone (the call back function when finish measure)
     */
    measureCell(index: number, onMeasureDone: (width: number) => void): void;
    focus(forceIntoFirstElement?: boolean): boolean;
    protected _onRenderCheck(props: IDetailsRowCheckProps): JSX.Element;
    private _getSelectionState(props);
    private _onSelectionChanged();
    private _onToggleSelection();
    private _onRootRef;
    private _getRowDragDropOptions();
    /**
     * update isDropping state based on the input value, which is used to change style during drag and drop
     *
     * when change to true, that means drag enter. we will add default dropping class name
     * or the custom dropping class name (return result from onDragEnter) to the root elemet.
     *
     * when change to false, that means drag leave. we will remove the dropping class name from root element.
     *
     * @private
     * @param {boolean} newValue (new isDropping state value)
     * @param {DragEvent} event (the event trigger dropping state change which can be dragenter, dragleave etc)
     */
    private _updateDroppingState(newValue, event);
}
